==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/eo/heo56.h <==
/****************************************************************************

  module      : heo56.h

  -------------------------------------------------------------------------

  responsible : JoergM

  special area: scheduling
  description : Kernel Task Scheduling
  
  last changed: 2000-02-12  14:36
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1999



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef HEO56_H
#define HEO56_H



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"

/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

/* --- VOS56KC / VEN56C ------------------------------------------------------- */

externC void                   vstop            ( tsp00_TaskId      pid );

externC void                   vcontinue        ( tsp00_TaskId      pid );

externC void                   vsuspend         ( tsp00_TaskId      pid,
												  tsp00_Uint1       suspend_level,
												  tsp00_Int2        suspend_reason );

externC tsp00_Bool             visresume        ( tsp00_TaskId      pid,
												  tsp00_Uint1       suspend_level);

externC void                   vresume          ( tsp00_TaskId      pid,
												  tsp00_Uint1       suspend_level);

externC void                   vwait            ( tsp00_TaskId             pid,
												  tsp00_Bool VAR_VALUE_REF ok );

externC void                   vsignal          ( tsp00_TaskId      pid,
												  tsp00_Bool        ok );

externC void                   vsleep           ( tsp00_TaskId      pid,
												  tsp00_Int2        limit );


externC void                   vreschedule_msec ( tsp00_TaskId      pid,
                                                  tsp00_Int4 VAR_VALUE_REF StartMsec,
                                                  tsp00_Int4 VAR_VALUE_REF RemainMsec );

externC void                   vLockDispatcher( tsp00_TaskId CurrentTaskId );

externC void                   vUnlockDispatcher( tsp00_TaskId CurrentTaskId );

#endif  /* HEO56_H */

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/eo/heo56.h <==
/****************************************************************************

  module      : heo56.h

  -------------------------------------------------------------------------

  responsible : JoergM

  special area: scheduling
  description : Kernel Task Scheduling
  
  last changed: 2000-02-12  14:36
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1999



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef HEO56_H
#define HEO56_H



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gsp00.h"

/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

/* --- VOS56KC / VEN56C ------------------------------------------------------- */

externC void                   vstop            ( tsp00_TaskId      pid );

externC void                   vcontinue        ( tsp00_TaskId      pid );

externC void                   vsuspend         ( tsp00_TaskId      pid,
												  tsp00_Uint1       suspend_level,
												  tsp00_Int2        suspend_reason );

externC tsp00_Bool             visresume        ( tsp00_TaskId      pid,
												  tsp00_Uint1       suspend_level);

externC void                   vresume          ( tsp00_TaskId      pid,
												  tsp00_Uint1       suspend_level);

externC void                   vwait            ( tsp00_TaskId             pid,
												  tsp00_Bool VAR_VALUE_REF ok );

externC void                   vsignal          ( tsp00_TaskId      pid,
												  tsp00_Bool        ok );

externC void                   vsleep           ( tsp00_TaskId      pid,
												  tsp00_Int2        limit );


externC void                   vreschedule_msec ( tsp00_TaskId      pid,
                                                  tsp00_Int4 VAR_VALUE_REF StartMsec,
                                                  tsp00_Int4 VAR_VALUE_REF RemainMsec );

externC void                   vSuspendForPageLock ( tsp00_TaskId      pid,
												     tsp00_Int2        suspend_reason,
                                                     tsp00_Int4        page_no );

#endif  /* HEO56_H */
